@@ -113,7 +113,6 @@ def _separate_buffers(substate, path, buffer_paths, buffers):
         raise ValueError("expected state to be a list or dict, not %r" % substate)
     return substate
 
-
 def _remove_buffers(state):
     """Return (state_without_buffers, buffer_paths, buffers) for binary message parts
 
@@ -283,6 +282,7 @@ def register(name=''):
     else:
         return reg(name)
 
+
 class Widget(LoggingHasTraits):
     #-------------------------------------------------------------------------
     # Class attributes
@@ -351,7 +351,6 @@ class Widget(LoggingHasTraits):
             state[widget.model_id] = widget._get_embed_state(drop_defaults=drop_defaults)
         return {'version_major': 2, 'version_minor': 0, 'state': state}
 
-
     def _get_embed_state(self, drop_defaults=False):
         state = {
             'model_name': self._model_name,
@@ -479,10 +478,15 @@ class Widget(LoggingHasTraits):
         """
         state = self.get_state(key=key)
         if len(state) > 0:
+            if self._property_lock:  # we need to keep this dict up to date with the front-end values
+                for name, value in state.items():
+                    if name in self._property_lock:
+                        self._property_lock[name] = value
             state, buffer_paths, buffers = _remove_buffers(state)
             msg = {'method': 'update', 'state': state, 'buffer_paths': buffer_paths}
             self._send(msg, buffers=buffers)
 
+
     def get_state(self, key=None, drop_defaults=False):
         """Gets the widget state, or a piece of it.
 
@@ -605,6 +609,7 @@ class Widget(LoggingHasTraits):
     #-------------------------------------------------------------------------
     # Support methods
     #-------------------------------------------------------------------------
+
     @contextmanager
     def _lock_property(self, **properties):
         """Lock a property-value pair.
@@ -701,26 +706,27 @@ class Widget(LoggingHasTraits):
 
     def _ipython_display_(self, **kwargs):
         """Called when `IPython.display.display` is called on the widget."""
-        if self._view_name is not None:
 
-            plaintext = repr(self)
-            if len(plaintext) > 110:
-                plaintext = plaintext[:110] + '…'
+        plaintext = repr(self)
+        if len(plaintext) > 110:
+            plaintext = plaintext[:110] + '…'
+        data = {
+            'text/plain': plaintext,
+        }
+        if self._view_name is not None:
             # The 'application/vnd.jupyter.widget-view+json' mimetype has not been registered yet.
             # See the registration process and naming convention at
             # http://tools.ietf.org/html/rfc6838
             # and the currently registered mimetypes at
             # http://www.iana.org/assignments/media-types/media-types.xhtml.
-            data = {
-                'text/plain': plaintext,
-                'application/vnd.jupyter.widget-view+json': {
-                    'version_major': 2,
-                    'version_minor': 0,
-                    'model_id': self._model_id
-                }
+            data['application/vnd.jupyter.widget-view+json'] = {
+                'version_major': 2,
+                'version_minor': 0,
+                'model_id': self._model_id
             }
-            display(data, raw=True)
+        display(data, raw=True)
 
+        if self._view_name is not None:
             self._handle_displayed(**kwargs)
 
     def _send(self, msg, buffers=None):
